==> dneop1_5.0.1.1_pg9.6_linux_x64.tar.gz: dneo/dneores/dneo/lang/ja_JP/js/vmtg.js <==
if (!desknets.Resource.vmtg) {
    desknets.Resource.vmtg = {};
}
$.extend(desknets.Resource.vmtg, {
    'remainingTimeMessage': 'あと{{remainingTime}}分でこの会議は終了します。',
    'extendableMessage': '延長する場合は<a href=\'#\' class=\'vmtg-open-extend-dialog\'>ここ</a>をクリックしてください。',
    'failToGetStreamMessage': 'カメラとマイクを認識できません。接続されているか確認してください。',
    'failToGetCameraMessage': 'カメラの取得に失敗しました。音声のみで会議に参加します。',
    'failToGetMicMessage': 'マイクの取得に失敗しました。映像のみで会議に参加します。',
    'failToGetStreamOthersMessage': '{{userName:hsN}}さんがカメラ/マイクの取得に失敗しました。',
    'failToGetCameraOthersMessage': '{{userName:hsN}}さんがカメラの取得に失敗しました。',
    'failToGetMicOthersMessage': '{{userName:hsN}}さんがマイクの取得に失敗しました。',
    'changePermission': '会議の情報が変更されました。<a href=\'\' onclick=\'location.reload();\'>ここ</a>をクリックすると、すぐに再表示します。',
    'canNotContinueMeeting': '会議の情報が変更され、会議を続けることができなくなったため、3秒後に退室します。',
    'screenSharedDialogTitle': '共有する画面を選択してください。',
    'screenShared' : '画面全体',
    'windowShared' : 'ウィンドウ',
    'screenNotAllowed': 'W:画面共有が許可されていません。',
    'extensionRequiredError': 'W:画面共有を開始できません。<br>\n以下のURLを参考にして、拡張機能「desknet\'s NEO WebMeeting Desktop Capture」をインストールしてください。',
    'extendDialogTitle': '会議の延長',
    'screenAssignDialogTitle': 'スクリーンに映す',
    'screenManageDialogTitle': 'レイアウト選択',
    'extendLabel' : '延長',
    'outofdateDialog': 'W:予約時間外のため、リアルタイムサーバーに接続できません。',
    'notAllowedDialog': 'W:この会議に対するアクセスが許可されていません。',
    'authWebhookFailure': 'W:接続に失敗しました。認証Webhookの設定に問題がある可能性があります。<br/>管理者に問い合わせてください。',
    'messageNewArrival': '新しいメッセージがあります',
    'messageSend': 'メッセージを送信しました',
    'changedLayoutByOther': '他の担当者がレイアウトを変更しました。',
    'confirmToExit': '退室してよろしいですか？',
    'confirmToEndMeeting': '会議を終了します。よろしいですか？',
    'assignDialogTargetUser': '対象ユーザー',
    'canNotExtendMeeting': 'すでに他の設備予約が登録されているか、または延長が許可されていない設備が含まれているためこのウェブ会議を延長することはできません。',
    'unselected': '未選択',
    'unknownDevice': '不明なデバイス'
});

==> dneop2_5.5.1.2_pg9.6_linux_x64.tar.gz: dneo/dneores/dneo/lang/ja_JP/js/vmtg.js <==
if (!desknets.Resource.vmtg) {
    desknets.Resource.vmtg = {};
}
$.extend(desknets.Resource.vmtg, {
    'remainingTimeMessage': 'あと{{remainingTime}}分でこの会議は終了します。',
    'extendableMessage': '延長する場合は<a href=\'#\' class=\'vmtg-open-extend-dialog\'>ここ</a>をクリックしてください。',
    'failToGetStreamMessage': 'カメラとマイクを認識できません。接続されているか確認してください。',
    'failToGetCameraMessage': 'カメラの取得に失敗しました。音声のみで会議に参加します。',
    'failToGetMicMessage': 'マイクの取得に失敗しました。映像のみで会議に参加します。',
    'failToGetStreamOthersMessage': '{{userName:hsN}}さんがカメラ/マイクの取得に失敗しました。',
    'failToGetCameraOthersMessage': '{{userName:hsN}}さんがカメラの取得に失敗しました。',
    'failToGetMicOthersMessage': '{{userName:hsN}}さんがマイクの取得に失敗しました。',
    'changePermission': '会議の情報が変更されました。<a href=\'\' onclick=\'location.reload();\'>ここ</a>をクリックすると、すぐに再表示します。',
    'canNotContinueMeeting': '会議の情報が変更され、会議を続けることができなくなったため、3秒後に退室します。',
    'screenSharedDialogTitle': '共有する画面を選択してください。',
    'screenShared' : '画面全体',
    'windowShared' : 'ウィンドウ',
    'screenNotAllowed': 'W:画面共有が許可されていません。',
    'extensionRequiredError': 'W:画面共有を開始できません。<br>\n以下のURLを参考にして、拡張機能「desknet\'s NEO WebMeeting Desktop Capture」をインストールしてください。',
    'extendDialogTitle': '会議の延長',
    'screenAssignDialogTitle': 'スクリーンに映す',
    'screenManageDialogTitle': 'レイアウト選択',
    'extendLabel' : '延長',
    'outofdateDialog': 'W:予約時間外のため、リアルタイムサーバーに接続できません。',
    'notAllowedDialog': 'W:この会議に対するアクセスが許可されていません。',
    'authWebhookFailure': 'W:接続に失敗しました。認証Webhookの設定に問題がある可能性があります。<br/>管理者に問い合わせてください。',
    'messageNewArrival': '新しいメッセージがあります',
    'messageSend': 'メッセージを送信しました',
    'changedLayoutByOther': '他の担当者がレイアウトを変更しました。',
    'confirmToExit': '退室してよろしいですか？',
    'confirmToEndMeeting': '会議を終了します。よろしいですか？',
    'assignDialogTargetUser': '対象ユーザー',
    'canNotExtendMeeting': 'すでに他の設備予約が登録されているか、または延長が許可されていない設備が含まれているためこのウェブ会議を延長することはできません。',
    'unselected': '未選択',
    'unknownDevice': '不明なデバイス',
    'videoQualitySettingDialogTitle': '映像品質設定',
    'startMeetingDialogTitle': '会議開始',
    'notChairErrorMessage': 'W:主催者ではなくなったため、会議を操作する権限がありません。'
});
